==> vokoscreen-ng_3.1.0.orig.tar.gz: vokoscreenNG-3.1.0/src/language/pt_PT.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt_PT">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Selecione um ou mais dispositivos</translation>
    </message>
</context>
<context>
    <name>QvkCameraController</name>
    <message>
        <source>Camera</source>
        <translation>Câmara</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Switch to Window</source>
        <translation>Mudar para janela</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Mudar para ecrã inteiro</translation>
    </message>
</context>
<context>
    <name>QvkDirectSoundController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Selecione um ou mais dispositivos</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Não foi encontrado nenhum gestor de ficheiros.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Por favor, instale um gestor de ficheiros.</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>A gravação não é iniciada, sem espaço suficiente em disco.</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>Foi atingido o limite de espaço em disco.</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Limite de espaço livre em disco</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>A gravação foi parada, sem espaço suficiente em disco.</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>Fullscreen</source>
        <translation>Ecrã inteiro</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Janela</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <translation>Não foi encontrado nenhum gestor de ficheiros.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Por favor, instale um gestor de ficheiros.</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Código-fonte</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Site</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Traduções</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Faz uma doação</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Selecione um ou mais dispositivos</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>Área</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>Começar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Sair</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Câmara</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Ampliação</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>Começar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Sair</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Diálogo</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Virar horizontalmente</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Virar verticalmente</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Inverter</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Cinza</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Preto e branco</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Eliminar a borda da janela</translation>
    </message>
    <message>
        <source>160x120</source>
        <translation>160x120</translation>
    </message>
    <message>
        <source>320x240</source>
        <translation>320x240</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>Configurações da câmara</translation>
    </message>
    <message>
        <source>640x480</source>
        <translation>640x480</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>Área</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Reinicializar</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Ampliação</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Contagem regressiva</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Tamanho do vídeo:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Espaço livre em disco:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informação</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Duração da gravação:</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Áudio</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Quadros de vídeo</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Codificador de vídeo</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Codificador de áudio</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Qualidade</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Não gravar o cursor do rato</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>Hora</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>Minuto</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>Iniciar o temporizador</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>Parar a gravação depois de</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Horas</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>Minutos</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Segundos</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Caminho para ficheiro de vídeo</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Limite de espaço livre em disco</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Mostrar no tabuleiro do sistema</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Segundos para esperar antes de gravar</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>Verificar actualizações</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Vídeo:</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Disponível</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Não disponível</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Iniciar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Terminar</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Executar</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Pasta</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Câmara</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Inverter</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Cinza</translation>
    </message>
    <message>
        <source>Send Report</source>
        <translation>Enviar relatório</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F10</source>
        <translation>Ctrl+Shift+F10</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F11</source>
        <translation>Ctrl+Shift+F11</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F12</source>
        <translation>Ctrl+Shift+F12</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>Executar a última gravação</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Abrir pasta</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F8</source>
        <translation>Ctrl+Shift+F8</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>Minimizado no início da gravação</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>Inicia minimizado</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Virar horizontalmente</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Virar verticalmente</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Preto e branco</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Eliminar a borda da janela</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Faz uma doação</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>Reinicializar todas as configurações no próximo início</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Direitos de autor e licença das imagens</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>Transmissão de ecrã</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Reprodutor</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Registo</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Direitos de autor e licença das imagens</translation>
    </message>
</context>
<context>
    <name>player</name>
    <message>
        <source>Play</source>
        <translation>Executar</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Terminar</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Abrir ficheiro</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Ecrã completo</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>Quadro anterior</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>Quadro seguinte</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Silenciar</translation>
    </message>
    <message>
        <source>Move menu</source>
        <translation>Deslocar o menu</translation>
    </message>
</context>
</TS>

==> vokoscreen-ng_3.3.0.orig.tar.gz: vokoscreenNG-3.3.0/src/language/pt_PT.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt_PT">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Selecione um ou mais dispositivos</translation>
    </message>
</context>
<context>
    <name>QvkCameraController</name>
    <message>
        <source>Camera</source>
        <translation>Câmara</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Switch to Window</source>
        <translation>Mudar para janela</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Mudar para ecrã inteiro</translation>
    </message>
</context>
<context>
    <name>QvkCiscoFinishDialog</name>
    <message>
        <source>The setup was successful.</source>
        <translation>Configuração finalizada com sucesso</translation>
    </message>
    <message>
        <source>Close this window and start vokoscreenNG again.</source>
        <translation>Feche esta janela e inicie vokoscreenNG novamente</translation>
    </message>
    <message>
        <source>Have fun with vokoscreenNG</source>
        <translation>Divirta-se com vokoscreenNG</translation>
    </message>
</context>
<context>
    <name>QvkDirectSoundController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Selecione um ou mais dispositivos</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Não foi encontrado nenhum gestor de ficheiros.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Por favor, instale um gestor de ficheiros.</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>A gravação não é iniciada, sem espaço suficiente em disco.</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>Foi atingido o limite de espaço em disco.</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Limite de espaço livre em disco</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>A gravação foi parada, sem espaço suficiente em disco.</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>Fullscreen</source>
        <translation>Ecrã inteiro</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Janela</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <translation>Não foi encontrado nenhum gestor de ficheiros.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Por favor, instale um gestor de ficheiros.</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Código-fonte</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Site</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Traduções</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Faz uma doação</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Selecione um ou mais dispositivos</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>Área</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise_wl</name>
    <message>
        <source>Area</source>
        <translation>Área</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>Começar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Sair</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Câmara</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Ampliação</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>Começar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Sair</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Câmara</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Ampliação</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Diálogo</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Virar horizontalmente</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Virar verticalmente</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Inverter</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Cinza</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Preto e branco</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Eliminar a borda da janela</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>Configurações da câmara</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>Área</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Reinicializar</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Ampliação</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Contagem regressiva</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Tamanho do vídeo:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Espaço livre em disco:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informação</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Duração da gravação:</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Áudio</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Quadros de vídeo</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Codificador de vídeo</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Codificador de áudio</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Qualidade</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Não gravar o cursor do rato</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>Hora</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>Minuto</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>Iniciar o temporizador</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>Parar a gravação depois de</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Horas</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>Minutos</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Segundos</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Caminho para ficheiro de vídeo</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Limite de espaço livre em disco</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Mostrar no tabuleiro do sistema</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Segundos para esperar antes de gravar</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>Verificar actualizações</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Vídeo:</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Disponível</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Não disponível</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Iniciar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Terminar</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Executar</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Pasta</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Câmara</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Inverter</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Cinza</translation>
    </message>
    <message>
        <source>Send Report</source>
        <translation>Enviar relatório</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F10</source>
        <translation>Ctrl+Shift+F10</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F11</source>
        <translation>Ctrl+Shift+F11</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F12</source>
        <translation>Ctrl+Shift+F12</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>Executar a última gravação</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Abrir pasta</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F8</source>
        <translation>Ctrl+Shift+F8</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>Minimizado no início da gravação</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>Inicia minimizado</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Virar horizontalmente</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Virar verticalmente</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Preto e branco</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Eliminar a borda da janela</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Faz uma doação</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>Reinicializar todas as configurações no próximo início</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Direitos de autor e licença das imagens</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>Transmissão de ecrã</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Reprodutor</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Registo</translation>
    </message>
    <message>
        <source>Automatically</source>
        <translation>Automaticamente</translation>
    </message>
    <message>
        <source>Create images of tabs </source>
        <translation>Criar imagens e separadores</translation>
    </message>
    <message>
        <source>License information</source>
        <translation>Informação sobre Licença</translation>
    </message>
    <message>
        <source>ON</source>
        <translation>LIGADO</translation>
    </message>
    <message>
        <source>OFF</source>
        <translation>DESLIGADO</translation>
    </message>
    <message>
        <source>Global keyboard shortcuts</source>
        <translation>Atalhos de teclado globais</translation>
    </message>
    <message>
        <source>Assigned shortcut keys.</source>
        <translation>Atalhos de teclado atribuídos</translation>
    </message>
    <message>
        <source>Keyboard shortcut not assigned or assigned more than once.</source>
        <translation>Atalho de teclado não atribuído ou atribuído mais do que uma vez</translation>
    </message>
    <message>
        <source>If it shows assigned but does not work, it is being used by another program.</source>
        <translation>Se é mostrado como atribuído mas não funciona, é porque está a ser usado por outro programa</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Direitos de autor e licença das imagens</translation>
    </message>
</context>
<context>
    <name>player</name>
    <message>
        <source>Play</source>
        <translation>Executar</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Terminar</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Abrir ficheiro</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Ecrã completo</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>Quadro anterior</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>Quadro seguinte</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Silenciar</translation>
    </message>
    <message>
        <source>Move menu</source>
        <translation>Deslocar o menu</translation>
    </message>
</context>
</TS>
